@@ -1,6 +1,6 @@
 import logging
 from pathlib import Path
-from typing import List, Optional
+from typing import Any, List, Literal, Optional
 
 import click
 
@@ -20,6 +20,11 @@ from .__version__ import __version__
 from .commands import config, profiles
 
 
+class RobotCodeFormatter(logging.Formatter):
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        super().__init__(*args, **kwargs)
+
+
 @click.group(
     cls=AliasedGroup,
     context_settings={"auto_envvar_prefix": "ROBOTCODE"},
@@ -49,6 +54,21 @@ from .commands import config, profiles
         If not specified, the default profile is used.
         """,
 )
+@click.option(
+    "-r",
+    "--root",
+    "root",
+    type=click.Path(exists=True, path_type=Path, dir_okay=True, file_okay=False, resolve_path=True),
+    multiple=False,
+    show_envvar=True,
+    help="Specifies the root path to be used for the project. It will be automatically detected if not provided.",
+)
+@click.option(
+    "--no-vcs",
+    is_flag=True,
+    show_envvar=True,
+    help="Ignore version control system directories (e.g., .git, .hg) when detecting the project root.",
+)
 @click.option(
     "-f",
     "--format",
@@ -95,6 +115,22 @@ from .commands import config, profiles
     show_default=True,
     show_envvar=True,
 )
+@click.option(
+    "--log-format",
+    type=str,
+    help="Sets the log format. See python logging documentation for more information.",
+    default=logging.BASIC_FORMAT,
+    show_default=True,
+    show_envvar=True,
+)
+@click.option(
+    "--log-style",
+    type=click.Choice(["%", "{", "$"]),
+    help="Sets the log style. See python logging documentation for more information.",
+    default="%",
+    show_default=True,
+    show_envvar=True,
+)
 @click.option(
     "--log-filename",
     type=click.Path(
@@ -160,6 +196,8 @@ def robotcode(
     app: Application,
     config_files: Optional[List[Path]],
     profiles: Optional[List[str]],
+    root: Optional[Path],
+    no_vcs: bool,
     format: Optional[OutputFormat],
     dry: bool,
     verbose: bool,
@@ -167,6 +205,8 @@ def robotcode(
     pager: Optional[bool],
     log: bool,
     log_level: str,
+    log_format: str,
+    log_style: Literal["%", "{", "$"],
     log_filename: Optional[str],
     log_calls: bool,
     default_path: Optional[List[str]],
@@ -189,6 +229,8 @@ def robotcode(
     app.config.profiles = profiles
     app.config.dry = dry
     app.config.verbose = verbose
+    app.config.root = root
+    app.config.no_vcs = no_vcs
 
     if color is None:
         app.config.colored_output = ColoredOutput.AUTO
@@ -210,10 +252,18 @@ def robotcode(
 
         logging.basicConfig(
             level=log_level,
-            format="%(name)s:%(levelname)s: %(message)s",
+            format=log_format,
+            style=log_style,
             filename=log_filename,
         )
 
+        try:
+            logging.root.handlers[0].formatter = RobotCodeFormatter(
+                fmt=log_format, style=log_style, defaults={"indent": ""}
+            )
+        except TypeError:
+            pass
+
     if debugpy:
         from robotcode.core.utils.debugpy import (
             start_debugpy,
@@ -240,9 +290,8 @@ def robotcode(
 robotcode.add_command(config)
 robotcode.add_command(profiles)
 
-for p in PluginManager().cli_commands:
-    for c in p:
-        robotcode.add_command(c)
+for c in PluginManager.instance().cli_commands:
+    robotcode.add_command(c)
 
 
 @robotcode.command()
